@@ -1,11 +1,14 @@
 package Linux::Info;
+
+our $VERSION = '0.2';
+
 use strict;
 use warnings;
 use Carp qw(croak);
 use POSIX qw(strftime);
 use UNIVERSAL;
+use Devel::AssertOS qw(Linux);
 use Linux::Info::Compilation;
-our $VERSION = '0.10'; # VERSION
 
 =head1 NAME
 
